@@ -4,7 +4,7 @@ import arviz as az
 import pystan as pystan
 
 from plotly.subplots import make_subplots
-from bayestestimation.model.best import model
+from bayestestimation.best import model
 from bayestestimation.bayesthelpers import _calculate_map
 from bayestestimation.bayestplotters import _get_centre_lines
 from bayestestimation.bayestplotters import _get_intervals 
@@ -32,7 +32,7 @@ class BayesTEstimation:
         
     def _compile_model(self):
         # Compiles the stan model in C++
-        return pystan.StanModel(model_code=model(), model_name='BEST')
+        return pystan.StanModel(model_code=model, model_name='BEST')
 
     def _check_sample_posterior_inputs(self):
         # Checks that parameters are in the correct format
